untdl.event.Event

Package untdl :: Module event :: Class Event |
[frames] | no frames]

# Class Event

source code

    object --+
             |
            Event

Known Subclasses:
  - KeyEvent
  - , MouseButtonEvent
  - , MouseMotion
  - , Quit

Base Event class.

You can easily subclass this to make your own events. Be sure to set the class attribute Event.type for it to be passed to a custom App ev_* method.

Instance Methods
__repr__(self) List an events public attributes when printed. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| type = `None` String constant representing the type of event.

Properties
Inherited from `object`: `__class__`

Method Details

### __repr__(self) (Representation operator) | source code
List an events public attributes when printed. Overrides: object.__repr__

Class Variable Details

  ### type String constant representing the type of event. The App ev_* methods depend on this attribute. Can be: 'QUIT', 'KEYDOWN', 'KEYUP', 'MOUSEDOWN', 'MOUSEUP', or 'MOUSEMOTION.' Value:
      None